==> scala-k8s-objects_native0.4_2.12-0.3.0-sources.jar: io/k8s/api/batch/v1/JobStatus.scala <==
package io.k8s.api.batch.v1

import dev.hnaderi.k8s.utils._

/** JobStatus represents the current state of a Job. */
final case class JobStatus(
  conditions : Option[Seq[io.k8s.api.batch.v1.JobCondition]] = None,
  uncountedTerminatedPods : Option[io.k8s.api.batch.v1.UncountedTerminatedPods] = None,
  completedIndexes : Option[String] = None,
  startTime : Option[io.k8s.apimachinery.pkg.apis.meta.v1.Time] = None,
  ready : Option[Int] = None,
  failed : Option[Int] = None,
  succeeded : Option[Int] = None,
  completionTime : Option[io.k8s.apimachinery.pkg.apis.meta.v1.Time] = None,
  active : Option[Int] = None
) {

  /** Returns a new data with conditions set to new value */
  def withConditions(value: Seq[io.k8s.api.batch.v1.JobCondition]) : JobStatus = copy(conditions = Some(value))
  /** Appends new values to conditions */
  def addConditions(newValues: io.k8s.api.batch.v1.JobCondition*) : JobStatus = copy(conditions = Some(conditions.fold(newValues)(_ ++ newValues)))
  /** if conditions has a value, transforms to the result of function*/
  def mapConditions(f: Seq[io.k8s.api.batch.v1.JobCondition] => Seq[io.k8s.api.batch.v1.JobCondition]) : JobStatus = copy(conditions = conditions.map(f))

  /** Returns a new data with uncountedTerminatedPods set to new value */
  def withUncountedTerminatedPods(value: io.k8s.api.batch.v1.UncountedTerminatedPods) : JobStatus = copy(uncountedTerminatedPods = Some(value))
  /** if uncountedTerminatedPods has a value, transforms to the result of function*/
  def mapUncountedTerminatedPods(f: io.k8s.api.batch.v1.UncountedTerminatedPods => io.k8s.api.batch.v1.UncountedTerminatedPods) : JobStatus = copy(uncountedTerminatedPods = uncountedTerminatedPods.map(f))

  /** Returns a new data with completedIndexes set to new value */
  def withCompletedIndexes(value: String) : JobStatus = copy(completedIndexes = Some(value))
  /** if completedIndexes has a value, transforms to the result of function*/
  def mapCompletedIndexes(f: String => String) : JobStatus = copy(completedIndexes = completedIndexes.map(f))

  /** Returns a new data with startTime set to new value */
  def withStartTime(value: io.k8s.apimachinery.pkg.apis.meta.v1.Time) : JobStatus = copy(startTime = Some(value))
  /** if startTime has a value, transforms to the result of function*/
  def mapStartTime(f: io.k8s.apimachinery.pkg.apis.meta.v1.Time => io.k8s.apimachinery.pkg.apis.meta.v1.Time) : JobStatus = copy(startTime = startTime.map(f))

  /** Returns a new data with ready set to new value */
  def withReady(value: Int) : JobStatus = copy(ready = Some(value))
  /** if ready has a value, transforms to the result of function*/
  def mapReady(f: Int => Int) : JobStatus = copy(ready = ready.map(f))

  /** Returns a new data with failed set to new value */
  def withFailed(value: Int) : JobStatus = copy(failed = Some(value))
  /** if failed has a value, transforms to the result of function*/
  def mapFailed(f: Int => Int) : JobStatus = copy(failed = failed.map(f))

  /** Returns a new data with succeeded set to new value */
  def withSucceeded(value: Int) : JobStatus = copy(succeeded = Some(value))
  /** if succeeded has a value, transforms to the result of function*/
  def mapSucceeded(f: Int => Int) : JobStatus = copy(succeeded = succeeded.map(f))

  /** Returns a new data with completionTime set to new value */
  def withCompletionTime(value: io.k8s.apimachinery.pkg.apis.meta.v1.Time) : JobStatus = copy(completionTime = Some(value))
  /** if completionTime has a value, transforms to the result of function*/
  def mapCompletionTime(f: io.k8s.apimachinery.pkg.apis.meta.v1.Time => io.k8s.apimachinery.pkg.apis.meta.v1.Time) : JobStatus = copy(completionTime = completionTime.map(f))

  /** Returns a new data with active set to new value */
  def withActive(value: Int) : JobStatus = copy(active = Some(value))
  /** if active has a value, transforms to the result of function*/
  def mapActive(f: Int => Int) : JobStatus = copy(active = active.map(f))
}

object JobStatus {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.batch.v1.JobStatus, T] = new Encoder[io.k8s.api.batch.v1.JobStatus, T] {
        def apply(o: io.k8s.api.batch.v1.JobStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("conditions", o.conditions)
            .write("uncountedTerminatedPods", o.uncountedTerminatedPods)
            .write("completedIndexes", o.completedIndexes)
            .write("startTime", o.startTime)
            .write("ready", o.ready)
            .write("failed", o.failed)
            .write("succeeded", o.succeeded)
            .write("completionTime", o.completionTime)
            .write("active", o.active)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, JobStatus] = new Decoder[T, JobStatus] {
      def apply(t: T): Either[String, JobStatus] = for {
          obj <- ObjectReader(t)
          conditions <- obj.readOpt[Seq[io.k8s.api.batch.v1.JobCondition]]("conditions")
          uncountedTerminatedPods <- obj.readOpt[io.k8s.api.batch.v1.UncountedTerminatedPods]("uncountedTerminatedPods")
          completedIndexes <- obj.readOpt[String]("completedIndexes")
          startTime <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.Time]("startTime")
          ready <- obj.readOpt[Int]("ready")
          failed <- obj.readOpt[Int]("failed")
          succeeded <- obj.readOpt[Int]("succeeded")
          completionTime <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.Time]("completionTime")
          active <- obj.readOpt[Int]("active")
      } yield JobStatus (
          conditions = conditions,
          uncountedTerminatedPods = uncountedTerminatedPods,
          completedIndexes = completedIndexes,
          startTime = startTime,
          ready = ready,
          failed = failed,
          succeeded = succeeded,
          completionTime = completionTime,
          active = active
        )
    }
}

==> scala-k8s-objects_native0.4_2.12-0.8.0-sources.jar: io/k8s/api/batch/v1/JobStatus.scala <==
package io.k8s.api.batch.v1

import dev.hnaderi.k8s.utils._

/** JobStatus represents the current state of a Job. */
final case class JobStatus(
  conditions : Option[Seq[io.k8s.api.batch.v1.JobCondition]] = None,
  uncountedTerminatedPods : Option[io.k8s.api.batch.v1.UncountedTerminatedPods] = None,
  completedIndexes : Option[String] = None,
  startTime : Option[io.k8s.apimachinery.pkg.apis.meta.v1.Time] = None,
  ready : Option[Int] = None,
  failed : Option[Int] = None,
  succeeded : Option[Int] = None,
  completionTime : Option[io.k8s.apimachinery.pkg.apis.meta.v1.Time] = None,
  active : Option[Int] = None
) {

  /** Returns a new data with conditions set to new value */
  def withConditions(value: Seq[io.k8s.api.batch.v1.JobCondition]) : JobStatus = copy(conditions = Some(value))
  /** Appends new values to conditions */
  def addConditions(newValues: io.k8s.api.batch.v1.JobCondition*) : JobStatus = copy(conditions = Some(conditions.fold(newValues)(_ ++ newValues)))
  /** if conditions has a value, transforms to the result of function*/
  def mapConditions(f: Seq[io.k8s.api.batch.v1.JobCondition] => Seq[io.k8s.api.batch.v1.JobCondition]) : JobStatus = copy(conditions = conditions.map(f))

  /** Returns a new data with uncountedTerminatedPods set to new value */
  def withUncountedTerminatedPods(value: io.k8s.api.batch.v1.UncountedTerminatedPods) : JobStatus = copy(uncountedTerminatedPods = Some(value))
  /** if uncountedTerminatedPods has a value, transforms to the result of function*/
  def mapUncountedTerminatedPods(f: io.k8s.api.batch.v1.UncountedTerminatedPods => io.k8s.api.batch.v1.UncountedTerminatedPods) : JobStatus = copy(uncountedTerminatedPods = uncountedTerminatedPods.map(f))

  /** Returns a new data with completedIndexes set to new value */
  def withCompletedIndexes(value: String) : JobStatus = copy(completedIndexes = Some(value))
  /** if completedIndexes has a value, transforms to the result of function*/
  def mapCompletedIndexes(f: String => String) : JobStatus = copy(completedIndexes = completedIndexes.map(f))

  /** Returns a new data with startTime set to new value */
  def withStartTime(value: io.k8s.apimachinery.pkg.apis.meta.v1.Time) : JobStatus = copy(startTime = Some(value))
  /** if startTime has a value, transforms to the result of function*/
  def mapStartTime(f: io.k8s.apimachinery.pkg.apis.meta.v1.Time => io.k8s.apimachinery.pkg.apis.meta.v1.Time) : JobStatus = copy(startTime = startTime.map(f))

  /** Returns a new data with ready set to new value */
  def withReady(value: Int) : JobStatus = copy(ready = Some(value))
  /** if ready has a value, transforms to the result of function*/
  def mapReady(f: Int => Int) : JobStatus = copy(ready = ready.map(f))

  /** Returns a new data with failed set to new value */
  def withFailed(value: Int) : JobStatus = copy(failed = Some(value))
  /** if failed has a value, transforms to the result of function*/
  def mapFailed(f: Int => Int) : JobStatus = copy(failed = failed.map(f))

  /** Returns a new data with succeeded set to new value */
  def withSucceeded(value: Int) : JobStatus = copy(succeeded = Some(value))
  /** if succeeded has a value, transforms to the result of function*/
  def mapSucceeded(f: Int => Int) : JobStatus = copy(succeeded = succeeded.map(f))

  /** Returns a new data with completionTime set to new value */
  def withCompletionTime(value: io.k8s.apimachinery.pkg.apis.meta.v1.Time) : JobStatus = copy(completionTime = Some(value))
  /** if completionTime has a value, transforms to the result of function*/
  def mapCompletionTime(f: io.k8s.apimachinery.pkg.apis.meta.v1.Time => io.k8s.apimachinery.pkg.apis.meta.v1.Time) : JobStatus = copy(completionTime = completionTime.map(f))

  /** Returns a new data with active set to new value */
  def withActive(value: Int) : JobStatus = copy(active = Some(value))
  /** if active has a value, transforms to the result of function*/
  def mapActive(f: Int => Int) : JobStatus = copy(active = active.map(f))
}

object JobStatus {

    implicit val encoder : Encoder[io.k8s.api.batch.v1.JobStatus] = new Encoder[io.k8s.api.batch.v1.JobStatus] {
        def apply[T : Builder](o: io.k8s.api.batch.v1.JobStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("conditions", o.conditions)
            .write("uncountedTerminatedPods", o.uncountedTerminatedPods)
            .write("completedIndexes", o.completedIndexes)
            .write("startTime", o.startTime)
            .write("ready", o.ready)
            .write("failed", o.failed)
            .write("succeeded", o.succeeded)
            .write("completionTime", o.completionTime)
            .write("active", o.active)
            .build
        }
    }

    implicit val decoder: Decoder[JobStatus] = new Decoder[JobStatus] {
      def apply[T : Reader](t: T): Either[String, JobStatus] = for {
          obj <- ObjectReader(t)
          conditions <- obj.readOpt[Seq[io.k8s.api.batch.v1.JobCondition]]("conditions")
          uncountedTerminatedPods <- obj.readOpt[io.k8s.api.batch.v1.UncountedTerminatedPods]("uncountedTerminatedPods")
          completedIndexes <- obj.readOpt[String]("completedIndexes")
          startTime <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.Time]("startTime")
          ready <- obj.readOpt[Int]("ready")
          failed <- obj.readOpt[Int]("failed")
          succeeded <- obj.readOpt[Int]("succeeded")
          completionTime <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.Time]("completionTime")
          active <- obj.readOpt[Int]("active")
      } yield JobStatus (
          conditions = conditions,
          uncountedTerminatedPods = uncountedTerminatedPods,
          completedIndexes = completedIndexes,
          startTime = startTime,
          ready = ready,
          failed = failed,
          succeeded = succeeded,
          completionTime = completionTime,
          active = active
        )
    }
}
